@@ -11,6 +11,7 @@ import inspect
 
 
 from .globaling import *
+from .odicting import odict
 
 from . import aiding
 from . import excepting
@@ -21,24 +22,11 @@ from . import acting
 from .consoling import getConsole
 console = getConsole()
 
-
-def CreateInstances(store):
-    """Create action instances
-       must be function so can recreate after clear registry
-       globals good for module self tests
-    """
-    #global traitDepth
-    #instance should be only one should use singleton or borg
-    traitDepth = DepthTrait(name = 'traitDepth', store = store)
-
-
-
 class Trait(acting.Actor):
     """Trait Class for configuration feature
 
     """
-    Counter = 0  
-    Names = {}
+    Registry = odict()
 
 class DepthTrait(Trait):
     """DepthTrait Trait
